<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

define('POCKET_ACTION_SUCCESS', 'success');
define('POCKET_ACTION_ERROR'  , 'error');

/**
 *  Actionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    Pocket
 */
class Pocket_Action
{
    /** @var    object  Pocket_Smarty       Smartyオブジェクト */
    var $smarty;

    /** @var    string  検証エラー時に遷移するAction名称 */
    var $viewAction;

    /**
     *  コンストラクタ
     *
     *  @access public
     */
    function Pocket_Action()
    {
    }

    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        return 'success';
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return boolean true,false
     */
    function validate(&$controller, &$request)
    {
        return true;
    }

    /**
     *  ログインユーザ検証（別ユーザであればエラー画面を表示）
     *
     *  @access public
     *  @param  string  $login_user_id      ログインユーザID
     *  @param  string  $target_user_id     ターゲットユーザID
     *  @param  boolean $is_dispError       エラー画面表示フラグ
     *  @return boolean true,false
     */
    function validate4Oneself($login_user_id, $target_user_id, $is_dispError = false)
    {
        if ($login_user_id != $target_user_id)
        {
            if ($is_dispError)
            {
                pocket_dispError('不正な操作がおこなわれました。');
            }
            return false;
        }
        return true;
    }

    /**
     *  有効フラグ
     *
     *  @access public
     *  @return boolean true,false
     */
    function isValid()
    {
        // エラー情報の存在チェック
        if ($this->smarty->get_template_vars('errors'))
        {
            return false;
        }
        return true;
    }

    /**
     *  認証アクションフラグ
     *
     *  @access public
     *  @return boolean true,false
     */
    function isSecure()
    {
        return true;
    }

    /**
     *  テンプレート変数の設定
     *
     *  @access public
     *  @param  string  $name               変数名
     *  @param  string  $value              値
     */
    function assign($name, $value = NULL)
    {
        $this->smarty->assign($name, $value);
    }

    /**
     *  テンプレート変数の追加
     *
     *  @access public
     *  @param  string  $name               配列変数名
     *  @param  string  $value              値
     */
    function append($name, $value = NULL)
    {
        $this->smarty->append($name, $value);
    }

    /**
     *  ページング情報をテンプレート変数に設定
     *
     *  @access public
     *  @param  integer $page               ページ番号
     *  @param  integer $page_size          ページサイズ
     *  @param  integer $hit_count          ヒット件数
     */
    function assignPagingInfo($page, $page_size, $hit_count)
    {
        // ページング情報の算出
        if ($hit_count != 0)
        {
            $page_count = ceil($hit_count / $page_size);
            $is_prev_page = ($page <= 1) ? false : true;
            $is_next_page = ($page >= $page_count) ? false : true;
        }
        $start_data_no = ($page - 1) * $page_size + 1;
        $end_data_no = ($page - 1) * $page_size + $page_size > $hit_count ? $hit_count : ($page - 1) * $page_size + $page_size;

        // ページング情報の設定
        $this->smarty->assign('page', $page);
        $this->smarty->assign('page_size', $page_size);
        $this->smarty->assign('hit_count', $hit_count);
        $this->smarty->assign('page_count', $page_count);
        $this->smarty->assign('is_prev_page', $is_prev_page);
        $this->smarty->assign('is_next_page', $is_next_page);
        $this->smarty->assign('start_data_no', $start_data_no);
        $this->smarty->assign('end_data_no', $end_data_no);
    }

    /**
     *  年月情報をテンプレート変数に設定
     *
     *  @access public
     *  @param  integer $year               年
     *  @param  integer $month              月
     */
    function assignYearMonthInfo($year, $month)
    {
        // 先月、来月の取得
        $last_month = getdate(mktime(0, 0, 0, $month - 1, 1, $year));
        $next_month = getdate(mktime(0, 0, 0, $month + 1, 1, $year));

        // 年月情報の設定
        $this->smarty->assign('year', $year);
        $this->smarty->assign('month', $month);
        $this->smarty->assign('last_year', $last_month['year']);
        $this->smarty->assign('last_month', $last_month['mon']);
        $this->smarty->assign('next_year', $next_month['year']);
        $this->smarty->assign('next_month', $next_month['mon']);
    }
}

?>
